Concepts
========

The purpose of this page is to help you understand how content integration work
fits more broadly within the Kolibri ecosystem.

The links below establish the shared vocabulary to facilitate communication between
content partners, the Learning Equality team, Kolibri users, and other stakeholders.

.. toctree::
   :maxdepth: 1

   introduction
   terminology
   content_workflows
   developer_workflows
   reviewing_channels
